
# Slot: role


the role played by the slot range

URI: [linkml:role](https://w3id.org/linkml/role)


## Domain and Range

[SlotDefinition](SlotDefinition.md) &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
